@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2016 Maxime DOYEN
+ *  Copyright (C) 1995-2018 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -467,6 +467,9 @@ guint32 *new_key;
 				newcat->imported = imported;
 
 				newcat->flags |= GF_SUB;
+				//#1713413 take parent type into account
+				if(parent->flags & GF_INCOME)
+					newcat->flags |= GF_INCOME;
 
 				DB( g_print(" -> insert subcat '%s' id: %d\n", newcat->name, newcat->key) );
 
@@ -661,7 +664,10 @@ void
 category_fill_usage(void)
 {
 GList *lcat;
-GList *lrul, *list;
+GList *lst_acc, *lnk_acc;
+GList *lnk_txn;
+GList *lpay, *lrul, *list;
+guint i, nbsplit;
 
 	lcat = list = g_hash_table_get_values(GLOBALS->h_cat);
 	while (list != NULL)
@@ -673,14 +679,46 @@ GList *lrul, *list;
 	g_list_free(lcat);
 
 
-	list = g_list_first(GLOBALS->ope_list);
+	lst_acc = g_hash_table_get_values(GLOBALS->h_acc);
+	lnk_acc = g_list_first(lst_acc);
+	while (lnk_acc != NULL)
+	{
+	Account *acc = lnk_acc->data;
+
+		lnk_txn = g_queue_peek_head_link(acc->txn_queue);
+		while (lnk_txn != NULL)
+		{
+		Transaction *txn = lnk_txn->data;
+
+			//#1689308 count split as well
+			if( txn->flags & OF_SPLIT )
+			{
+				nbsplit = da_splits_count(txn->splits);
+				for(i=0;i<nbsplit;i++)
+				{
+				Split *split = txn->splits[i];
+					
+					category_fill_usage_count(split->kcat);
+				}
+			}
+			else
+				category_fill_usage_count(txn->kcat);		
+
+			lnk_txn = g_list_next(lnk_txn);
+		}
+		lnk_acc = g_list_next(lnk_acc);
+	}
+	g_list_free(lst_acc);
+
+	lpay = list = g_hash_table_get_values(GLOBALS->h_pay);
 	while (list != NULL)
 	{
-	Transaction *entry = list->data;
-		
+	Payee *entry = list->data;
+
 		category_fill_usage_count(entry->kcat);
 		list = g_list_next(list);
 	}
+	g_list_free(lpay);
 
 
 	list = g_list_first(GLOBALS->arc_list);
@@ -688,7 +726,20 @@ GList *lrul, *list;
 	{
 	Archive *entry = list->data;
 
-		category_fill_usage_count(entry->kcat);
+		//#1689308 count split as well
+		if( entry->flags & OF_SPLIT )
+		{
+			nbsplit = da_splits_count(entry->splits);
+			for(i=0;i<nbsplit;i++)
+			{
+			Split *split = entry->splits[i];
+				
+				category_fill_usage_count(split->kcat);
+			}
+		}
+		else
+			category_fill_usage_count(entry->kcat);
+
 		list = g_list_next(list);
 	}
 
@@ -702,40 +753,55 @@ GList *lrul, *list;
 		list = g_list_next(list);
 	}
 	g_list_free(lrul);
+
 }
 
 
 void
 category_move(guint32 key1, guint32 key2)
 {
+GList *lst_acc, *lnk_acc;
+GList *lnk_txn;
 GList *lrul, *list;
 guint i, nbsplit;
 
-	list = g_list_first(GLOBALS->ope_list);
-	while (list != NULL)
+	lst_acc = g_hash_table_get_values(GLOBALS->h_acc);
+	lnk_acc = g_list_first(lst_acc);
+	while (lnk_acc != NULL)
 	{
-	Transaction *entry = list->data;
-		if(entry->kcat == key1)
-		{
-			entry->kcat = key2;
-			entry->flags |= OF_CHANGED;
-		}
+	Account *acc = lnk_acc->data;
 
-		// move split category #1340142
-		nbsplit = da_transaction_splits_count(entry);
-		for(i=0;i<nbsplit;i++)
+		lnk_txn = g_queue_peek_head_link(acc->txn_queue);
+		while (lnk_txn != NULL)
 		{
-		Split *split = entry->splits[i];
-
-			if( split->kcat == key1 )
+		Transaction *txn = lnk_txn->data;
+		
+			if(txn->kcat == key1)
 			{
-				split->kcat = key2;
-				entry->flags |= OF_CHANGED;
+				txn->kcat = key2;
+				txn->flags |= OF_CHANGED;
 			}
-		}
 
-		list = g_list_next(list);
+			// move split category #1340142
+			nbsplit = da_splits_count(txn->splits);
+			for(i=0;i<nbsplit;i++)
+			{
+			Split *split = txn->splits[i];
+
+				if( split->kcat == key1 )
+				{
+					split->kcat = key2;
+					txn->flags |= OF_CHANGED;
+				}
+			}
+
+			lnk_txn = g_list_next(lnk_txn);
+		}
+		
+		lnk_acc = g_list_next(lnk_acc);
 	}
+	g_list_free(lst_acc);
+
 
 	list = g_list_first(GLOBALS->arc_list);
 	while (list != NULL)
@@ -930,17 +996,15 @@ const gchar *encoding;
 				if( tmpstr != NULL )
 				{
 					DB( g_print(" + strip %s\n", tmpstr) );
-
 					hb_string_strip_crlf(tmpstr);
 
 					DB( g_print(" + split\n") );
-
 					str_array = g_strsplit (tmpstr, ";", 3);
 					// type; sign; name
 
 					if( g_strv_length (str_array) != 3 )
 					{
-						*error = _("invalid csv format");
+						*error = _("invalid CSV format");
 						retval = FALSE;
 						DB( g_print(" + error %s\n", *error) );
 					}
@@ -1056,6 +1120,14 @@ GList *lcat, *list;
 	return retval;
 }
 
+gint category_type_get(Category *item)
+{
+	if( (item->flags & (GF_INCOME)) )
+		return 1;
+	return -1;
+}
+
+
 
 static gint category_change_type_eval(Category *item, gboolean isIncome)
 {
