@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2018 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -31,6 +31,8 @@
 #include "ui-payee.h"
 #include "ui-category.h"
 #include "ui-filter.h"
+#include "ui-transaction.h"
+
 
 /****************************************************************************/
 /* Debug macros                                                             */
@@ -55,20 +57,22 @@ static void ui_reptime_action_viewline(GtkAction *action, gpointer user_data);
 static void ui_reptime_action_detail(GtkAction *action, gpointer user_data);
 //static void ui_reptime_action_filter(GtkAction *action, gpointer user_data);
 static void ui_reptime_action_refresh(GtkAction *action, gpointer user_data);
-static void ui_reptime_action_export(GtkAction *action, gpointer user_data);
 
-//static void ui_reptime_list_set_cur(GtkTreeView *treeview, guint32 kcur);
+static void ui_reptime_list_set_cur(GtkTreeView *treeview, guint32 kcur);
 
 
+static GtkRadioActionEntry radio_entries[] = {
+  { "List"    , ICONNAME_HB_VIEW_LIST  , N_("List")   , NULL,    N_("View results as list")  , 0 },
+  { "Line"    , ICONNAME_HB_VIEW_LINE  , N_("Line")   , NULL,    N_("View results as lines") , 1 },
+//  { "Column"  , ICONNAME_HB_VIEW_COLUMN, N_("Column") , NULL,    N_("View results as column"), 2 },
+};
+static guint n_radio_entries = G_N_ELEMENTS (radio_entries);
+
 static GtkActionEntry entries[] = {
-  { "List"    , ICONNAME_HB_VIEW_LIST  , N_("List")   , NULL,    N_("View results as list")  , G_CALLBACK (ui_reptime_action_viewlist) },
-  { "Line"    , ICONNAME_HB_VIEW_LINE  , N_("Line")   , NULL,    N_("View results as lines") , G_CALLBACK (ui_reptime_action_viewline) },
-//  { "Column"  , ICONNAME_HB_VIEW_COLUMN, N_("Column") , NULL,    N_("View results as column"), G_CALLBACK (ui_reptime_action_viewcolumn) },
-
 //  { "Filter"  , ICONNAME_HB_FILTER    , N_("Filter") , NULL,   N_("Edit the filter"), G_CALLBACK (ui_reptime_action_filter) },
   { "Refresh" , ICONNAME_REFRESH   , N_("Refresh"), NULL,   N_("Refresh results"), G_CALLBACK (ui_reptime_action_refresh) },
 
-  { "Export" , ICONNAME_HB_FILE_EXPORT, N_("Export")  , NULL,   N_("Export as CSV"), G_CALLBACK (ui_reptime_action_export) },
+//  { "Export" , ICONNAME_HB_FILE_EXPORT, N_("Export")  , NULL,   N_("Export as CSV"), G_CALLBACK (ui_reptime_action_export) },
 };
 static guint n_entries = G_N_ELEMENTS (entries);
 
@@ -95,7 +99,8 @@ static const gchar *ui_info =
 //"    <toolitem action='Filter'/>"
 "    <toolitem action='Refresh'/>"
 "      <separator/>"
-"    <toolitem action='Export'/>"
+//"    <toolitem action='Export'/>"
+//		replaced by a menubutton
 "  </toolbar>"
 "</ui>";
 
@@ -104,7 +109,6 @@ static void ui_reptime_date_change(GtkWidget *widget, gpointer user_data);
 static void ui_reptime_range_change(GtkWidget *widget, gpointer user_data);
 static void ui_reptime_detail(GtkWidget *widget, gpointer user_data);
 static void ui_reptime_update(GtkWidget *widget, gpointer user_data);
-static void ui_reptime_export_csv(GtkWidget *widget, gpointer user_data);
 static void ui_reptime_compute(GtkWidget *widget, gpointer user_data);
 static void ui_reptime_sensitive(GtkWidget *widget, gpointer user_data);
 static void ui_reptime_toggle_detail(GtkWidget *widget, gpointer user_data);
@@ -113,7 +117,7 @@ static void ui_reptime_update_daterange(GtkWidget *widget, gpointer user_data);
 static GtkWidget *ui_list_reptime_create(void);
 
 static gint ui_list_reptime_compare_func (GtkTreeModel *model, GtkTreeIter  *a, GtkTreeIter  *b, gpointer      userdata);
-
+static GString *ui_list_reptime_to_string(GtkTreeView *treeview, gboolean clipboard);
 
 
 gchar *CYA_TIMESELECT[] = { N_("Account"), N_("Category"), N_("Payee"), NULL };
@@ -175,6 +179,23 @@ struct ui_reptime_data *data = user_data;
 }*/
 
 
+static void ui_reptime_action_mode (GtkRadioAction *action, GtkRadioAction *current, gpointer user_data)
+{
+gint value;
+
+	value = gtk_radio_action_get_current_value(GTK_RADIO_ACTION(action));
+	switch( value )
+	{
+		case 0:
+			ui_reptime_action_viewlist(GTK_ACTION(action), user_data);
+			break;
+		case 1:
+			ui_reptime_action_viewline(GTK_ACTION(action), user_data);
+			break;
+	}
+}
+
+
 static void ui_reptime_action_detail(GtkAction *action, gpointer user_data)
 {
 struct ui_reptime_data *data = user_data;
@@ -202,12 +223,12 @@ struct ui_reptime_data *data = user_data;
 	ui_reptime_compute(data->window, NULL);
 }
 
-static void ui_reptime_action_export(GtkAction *action, gpointer user_data)
+/*static void ui_reptime_action_export(GtkAction *action, gpointer user_data)
 {
 struct ui_reptime_data *data = user_data;
 
 	ui_reptime_export_csv(data->window, NULL);
-}
+}*/
 
 
 
@@ -287,6 +308,7 @@ gint year_from, year_ope, pos;
 	return(pos);
 }
 
+
 static void ui_reptime_date_change(GtkWidget *widget, gpointer user_data)
 {
 struct ui_reptime_data *data;
@@ -376,7 +398,7 @@ struct ui_reptime_data *data;
 guint active = GPOINTER_TO_INT(user_data);
 guint tmpfor, tmpslice;
 gboolean showall;
-guint32 from, to;
+guint32 from;
 guint i;
 GList *list;
 GtkTreeModel *model;
@@ -409,7 +431,7 @@ guint32 selkey;
 
 	//get our min max date
 	from = data->filter->mindate;
-	to   = data->filter->maxdate;
+	//to   = data->filter->maxdate;
 
 	/* clear and detach our model */
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_detail));
@@ -421,54 +443,34 @@ guint32 selkey;
 		gtk_tree_view_set_model(GTK_TREE_VIEW(data->LV_detail), NULL); /* Detach model from view */
 
 		/* fill in the model */
-		list = g_list_first(GLOBALS->ope_list);
+		list = g_queue_peek_head_link(data->txn_queue);
 		while (list != NULL)
 		{
 		Transaction *ope = list->data;
-		Account *acc;
+		guint32 pos = 0;
+		gboolean include = FALSE;
 
 			//DB( g_print(" get %s\n", ope->ope_Word) );
 
-			acc = da_acc_get(ope->kacc);
-			if(acc == NULL) goto next1;
-			if((acc->flags & (AF_CLOSED|AF_NOREPORT))) goto next1;
-
-			//filter here
-			if( !(ope->status == TXN_STATUS_REMIND) && ope->date >= from && ope->date <= to)
+			switch(tmpfor)
 			{
-			guint32 pos = 0;
-			gboolean include = FALSE;
-
-				switch(tmpfor)
+				case FOR_REPTIME_ACCOUNT:
+					if( selkey == ope->kacc )
+						include = TRUE;
+					break;
+				case FOR_REPTIME_CATEGORY:
 				{
-					case FOR_REPTIME_ACCOUNT:
-						if( selkey == ope->kacc )
-							include = TRUE;
-						break;
-					case FOR_REPTIME_CATEGORY:
+				Category *catentry;
+				
+					if( ope->flags & OF_SPLIT )
 					{
-					Category *catentry;
+					guint nbsplit = da_splits_count(ope->splits);
+					Split *split;
 					
-						if( ope->flags & OF_SPLIT )
+						for(i=0;i<nbsplit;i++)
 						{
-						guint nbsplit = da_transaction_splits_count(ope);
-						Split *split;
-						
-							for(i=0;i<nbsplit;i++)
-							{
-								split = ope->splits[i];
-								catentry = da_cat_get(split->kcat);
-								if(catentry != NULL)	//#1340142
-								{
-									if( selkey == catentry->parent || selkey == catentry->key )
-										include = TRUE;
-
-								}
-							}
-						}
-						else
-						{							
-							catentry = da_cat_get(ope->kcat);
+							split = ope->splits[i];
+							catentry = da_cat_get(split->kcat);
 							if(catentry != NULL)	//#1340142
 							{
 								if( selkey == catentry->parent || selkey == catentry->key )
@@ -477,55 +479,65 @@ guint32 selkey;
 							}
 						}
 					}
+					else
+					{							
+						catentry = da_cat_get(ope->kcat);
+						if(catentry != NULL)	//#1340142
+						{
+							if( selkey == catentry->parent || selkey == catentry->key )
+								include = TRUE;
+
+						}
+					}
+				}
+					break;
+				case FOR_REPTIME_PAYEE:
+					if( selkey == ope->kpay )
+						include = TRUE;
+					break;
+			}
+
+			if( include == TRUE || showall == TRUE )
+			{
+
+				switch(tmpslice)
+				{
+					case GROUPBY_REPTIME_DAY:
+						pos = ope->date - from;
 						break;
-					case FOR_REPTIME_PAYEE:
-						if( selkey == ope->kpay )
-							include = TRUE;
+
+					case GROUPBY_REPTIME_WEEK:
+						pos = (ope->date - from)/7;
+						break;
+
+					case GROUPBY_REPTIME_MONTH:
+						pos = DateInMonth(from, ope->date);
+						break;
+
+					case GROUPBY_REPTIME_QUARTER:
+						pos = DateInQuarter(from, ope->date);
+						break;
+
+					case GROUPBY_REPTIME_YEAR:
+						pos = DateInYear(from, ope->date);
 						break;
 				}
 
-				if( include == TRUE || showall == TRUE )
+				DB( g_print("** pos=%d\n", pos) );
+
+				//insert
+				if( pos == active )
 				{
 
-					switch(tmpslice)
-					{
-						case GROUPBY_REPTIME_DAY:
-							pos = ope->date - from;
-							break;
-
-						case GROUPBY_REPTIME_WEEK:
-							pos = (ope->date - from)/7;
-							break;
-
-						case GROUPBY_REPTIME_MONTH:
-							pos = DateInMonth(from, ope->date);
-							break;
-
-						case GROUPBY_REPTIME_QUARTER:
-							pos = DateInQuarter(from, ope->date);
-							break;
-
-						case GROUPBY_REPTIME_YEAR:
-							pos = DateInYear(from, ope->date);
-							break;
-					}
-
-					DB( g_print("** pos=%d\n", pos) );
-
-					//insert
-					if( pos == active )
-					{
-
-						gtk_list_store_append (GTK_LIST_STORE(model), &iter);
-				 		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
-							LST_DSPOPE_DATAS, ope,
-							-1);
-					}
+					gtk_list_store_append (GTK_LIST_STORE(model), &iter);
+			 		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
+						LST_DSPOPE_DATAS, ope,
+						-1);
 				}
 
 
 			}
-next1:
+
 			list = g_list_next(list);
 		}
 
@@ -533,6 +545,7 @@ next1:
 		gtk_tree_view_set_model(GTK_TREE_VIEW(data->LV_detail), model);
 		g_object_unref(model);
 
+		gtk_tree_view_columns_autosize( GTK_TREE_VIEW(data->LV_detail) );
 	}
 
 }
@@ -570,6 +583,7 @@ gchar *title;
 
 	gtk_chart_show_legend(GTK_CHART(data->RE_line), FALSE, FALSE);
 	gtk_chart_show_xval(GTK_CHART(data->RE_line), TRUE);
+	gtk_chart_show_average(GTK_CHART(data->RE_line), data->average, TRUE);
 
 	////TRANSLATORS: example 'Expense by Category'
 	title = g_strdup_printf(_("%s Over Time"), _(CYA_TIMESELECT[tmpfor]) );
@@ -585,25 +599,98 @@ gchar *title;
 	
 }
 
-static void ui_reptime_export_csv(GtkWidget *widget, gpointer user_data)
+
+static void ui_reptime_export_result_clipboard(GtkWidget *widget, gpointer user_data)
+{
+struct ui_reptime_data *data;
+GtkClipboard *clipboard;
+GString *node;
+
+	DB( g_print("\n[reptime] export result clipboard\n") );
+
+	data = user_data;
+	//data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	node = ui_list_reptime_to_string(GTK_TREE_VIEW(data->LV_report), TRUE);
+
+	clipboard = gtk_clipboard_get_default(gdk_display_get_default());
+	gtk_clipboard_set_text(clipboard, node->str, node->len);
+
+	g_string_free(node, TRUE);
+}
+
+
+static void ui_reptime_export_result_csv(GtkWidget *widget, gpointer user_data)
 {
 struct ui_reptime_data *data;
-GtkTreeModel *model;
-GtkTreeIter	iter;
-gboolean valid;
 gchar *filename = NULL;
+GString *node;
 GIOChannel *io;
-gchar *outstr, *name;
+gchar *name;
 gint tmpfor;
 
-	DB( g_print("\n[reptime] export csv\n") );
+	DB( g_print("\n[reptime] export result csv\n") );
 
-	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+	data = user_data;
+	//data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
 	tmpfor  = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_for));
-
 	name = g_strdup_printf("hb-reptime_%s.csv", CYA_TIMESELECT[tmpfor]);
 
+	if( ui_file_chooser_csv(GTK_WINDOW(data->window), GTK_FILE_CHOOSER_ACTION_SAVE, &filename, name) == TRUE )
+	{
+		DB( g_print(" + filename is %s\n", filename) );
+		io = g_io_channel_new_file(filename, "w", NULL);
+		if(io != NULL)
+		{
+			node = ui_list_reptime_to_string(GTK_TREE_VIEW(data->LV_report), FALSE);
+			g_io_channel_write_chars(io, node->str, -1, NULL, NULL);
+			g_io_channel_unref (io);
+			g_string_free(node, TRUE);
+		}
+		g_free( filename );
+	}
+	g_free(name);
+}
+
+
+static void ui_reptime_export_detail_clipboard(GtkWidget *widget, gpointer user_data)
+{
+struct ui_reptime_data *data;
+GtkClipboard *clipboard;
+GString *node;
+
+	DB( g_print("\n[reptime] export detail clipboard\n") );
+
+	data = user_data;
+	//data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), TRUE);
+
+	clipboard = gtk_clipboard_get_default(gdk_display_get_default());
+	gtk_clipboard_set_text(clipboard, node->str, node->len);
+
+	g_string_free(node, TRUE);
+}
+
+
+static void ui_reptime_export_detail_csv(GtkWidget *widget, gpointer user_data)
+{
+struct ui_reptime_data *data;
+gchar *filename = NULL;
+GString *node;
+GIOChannel *io;
+gchar *name;
+gint tmpfor;
+
+	DB( g_print("\n[reptime] export detail csv\n") );
+
+	data = user_data;
+	//data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	tmpfor  = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_for));
+	name = g_strdup_printf("hb-reptime-detail_%s.csv", CYA_TIMESELECT[tmpfor]);
+
 	if( ui_file_chooser_csv(GTK_WINDOW(data->window), GTK_FILE_CHOOSER_ACTION_SAVE, &filename, name) == TRUE )
 	{
 		DB( g_print(" + filename is %s\n", filename) );
@@ -611,44 +698,17 @@ gint tmpfor;
 		io = g_io_channel_new_file(filename, "w", NULL);
 		if(io != NULL)
 		{
-			// header
-			outstr = g_strdup_printf("%s;%s;\n", _("Time slice"), _("Amount"));
-			g_io_channel_write_chars(io, outstr, -1, NULL, NULL);
-
-			model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_report));
-			valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
-
-			while (valid)
-			{
-			gchar *name;
-			gdouble amount;
-
-				gtk_tree_model_get (model, &iter,
-					//LST_REPTIME_KEY, i,
-					LST_REPTIME_TITLE  , &name,
-					LST_REPTIME_AMOUNT , &amount,
-
-					-1);
-
-				outstr = g_strdup_printf("%s;%.2f\n", name, amount);
-				g_io_channel_write_chars(io, outstr, -1, NULL, NULL);
-
-				DB( g_print("%s", outstr) );
-
-				g_free(outstr);
-
-				valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
-			}
+			node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), FALSE);
+			g_io_channel_write_chars(io, node->str, -1, NULL, NULL);
 
 			g_io_channel_unref (io);
+			g_string_free(node, TRUE);
 		}
 
 		g_free( filename );
 	}
 
 	g_free(name);
-
-
 }
 
 
@@ -742,18 +802,23 @@ guint32 selkey;
 
 	DB( g_print(" for=%d, view by=%d :: key=%d\n", tmpfor, tmpslice, selkey) );
 
-	/* do nothing if no transaction */
-	if(g_list_length(GLOBALS->ope_list) == 0) return;
-
 	//to remove > 5.0.2
-	//filter_preset_daterange_set(data->filter, data->filter->range, data->accnum);
-	//ui_reptime_update_quickdate(widget, NULL);
+	//#1715532 5.0.5: no... but only showall
+	if(showall == TRUE)
+	{
+		filter_preset_daterange_set(data->filter, data->filter->range, data->accnum);
+		ui_reptime_update_quickdate(widget, NULL);
+	}
 
 	//get our min max date
 	from = data->filter->mindate;
 	to   = data->filter->maxdate;
 	if(to < from) return;
 
+	g_queue_free (data->txn_queue);
+	data->txn_queue = hbfile_transaction_get_partial(data->filter->mindate, data->filter->maxdate);
+
+
 	/* count number or results */
 	switch(tmpslice)
 	{
@@ -796,124 +861,48 @@ guint32 selkey;
 
 	if(tmp_amount)
 	{
-	Account *acc;	
+	guint32 kcur;
 		
 		/* set currency */
-		/*
+		kcur = GLOBALS->kcur;
 		if( (tmpfor == FOR_REPTIME_ACCOUNT) && (showall == FALSE) )
 		{
-			if(acc = da_acc_get(selkey))
+		Account *acc = da_acc_get(selkey);
+
+			if( acc != NULL )
 			{
-				//ui_reptime_list_set_cur(GTK_TREE_VIEW(data->LV_report), acc->kcur);
-				//gtk_chart_set_currency(GTK_CHART(data->RE_line), acc->kcur);
+				kcur = acc->kcur;
 			}
 		}
-		else
-		{
-			//ui_reptime_list_set_cur(GTK_TREE_VIEW(data->LV_report), GLOBALS->kcur);
-			//gtk_chart_set_currency(GTK_CHART(data->RE_line), GLOBALS->kcur);
-		}*/
-			
+		
+		ui_reptime_list_set_cur(GTK_TREE_VIEW(data->LV_report), kcur);
+		gtk_chart_set_currency(GTK_CHART(data->RE_line), kcur);
+		
 	/* compute the results */
-		list = g_list_first(GLOBALS->ope_list);
+		list = g_queue_peek_head_link(data->txn_queue);
 		while (list != NULL)
 		{
 		Transaction *ope = list->data;
+		gboolean include = FALSE;
 
 			//debug
-			DB( g_print("** testing '%s', cat=%d==> %d\n", ope->wording, ope->kcat, filter_test(data->filter, ope)) );
-
-			acc = da_acc_get(ope->kacc);
-			if(acc == NULL) goto next1;
-			if((acc->flags & (AF_CLOSED|AF_NOREPORT))) goto next1;
-
+			DB( g_print("** testing '%s', cat=%d==> %d\n", ope->memo, ope->kcat, filter_test(data->filter, ope)) );
 
 			// add usage of payee or category
-			if( !(ope->status == TXN_STATUS_REMIND) && ope->date >= from && ope->date <= to)
-			//if( (filter_test(data->filter, ope) == 1) )
+			switch(tmpfor)
 			{
-			gboolean include = FALSE;
-
-				switch(tmpfor)
+				case FOR_REPTIME_ACCOUNT:
+					if( selkey == ope->kacc )
+						include = TRUE;
+					break;
+				case FOR_REPTIME_CATEGORY:
 				{
-					case FOR_REPTIME_ACCOUNT:
-						if( selkey == ope->kacc )
-							include = TRUE;
-						break;
-					case FOR_REPTIME_CATEGORY:
-					{
-					Category *catentry;
-					
-						if( ope->flags & OF_SPLIT )
-						{
-						guint nbsplit = da_transaction_splits_count(ope);
-						Split *split;
-						
-							for(i=0;i<nbsplit;i++)
-							{
-								split = ope->splits[i];
-								catentry = da_cat_get(split->kcat);
-								if(catentry != NULL)	//#1340142
-								{
-									if( selkey == catentry->parent || selkey == catentry->key )
-										include = TRUE;
-								}
-							}
-						}
-						else
-						{							
-							catentry = da_cat_get(ope->kcat);
-							if(catentry != NULL)	//#1340142
-							{
-								if( selkey == catentry->parent || selkey == catentry->key )
-									include = TRUE;
-							}
-						}
-						
-					}
-						break;
-					case FOR_REPTIME_PAYEE:
-						if( selkey == ope->kpay )
-							include = TRUE;
-						break;
-				}
-
-				if( include == TRUE || showall == TRUE)
-				{
-				guint32 pos = 0;
-				gdouble trn_amount;
+				Category *catentry;
 				
-					switch(tmpslice)
+					if( ope->flags & OF_SPLIT )
 					{
-						case GROUPBY_REPTIME_DAY:
-							pos = ope->date - from;
-							break;
-
-						case GROUPBY_REPTIME_WEEK:
-							pos = (ope->date - from)/7;
-							break;
-
-						case GROUPBY_REPTIME_MONTH:
-							pos = DateInMonth(from, ope->date);
-							break;
-
-						case GROUPBY_REPTIME_QUARTER:
-							pos = DateInQuarter(from, ope->date);
-							break;
-
-						case GROUPBY_REPTIME_YEAR:
-							pos = DateInYear(from, ope->date);
-							break;
-					}
-
-					acc = da_acc_get(ope->kacc);
-					trn_amount = 0.0;
-					
-					if( tmpfor == FOR_REPTIME_CATEGORY && ope->flags & OF_SPLIT )
-					{
-					guint nbsplit = da_transaction_splits_count(ope);
+					guint nbsplit = da_splits_count(ope->splits);
 					Split *split;
-					Category *catentry;
 					
 						for(i=0;i<nbsplit;i++)
 						{
@@ -922,23 +911,87 @@ guint32 selkey;
 							if(catentry != NULL)	//#1340142
 							{
 								if( selkey == catentry->parent || selkey == catentry->key )
-									trn_amount += split->amount;
+									include = TRUE;
 							}
 						}
 					}
 					else
-						trn_amount = ope->amount;
-
+					{							
+						catentry = da_cat_get(ope->kcat);
+						if(catentry != NULL)	//#1340142
+						{
+							if( selkey == catentry->parent || selkey == catentry->key )
+								include = TRUE;
+						}
+					}
 					
-					//trn_amount = to_base_amount(trn_amount, acc->kcur);
-
-					DB( g_print("** pos=%d will add %.2f to \n", pos, trn_amount) );
-
-					tmp_amount[pos] += trn_amount;
-
 				}
+					break;
+				case FOR_REPTIME_PAYEE:
+					if( selkey == ope->kpay )
+						include = TRUE;
+					break;
 			}
-next1:
+
+			if( include == TRUE || showall == TRUE)
+			{
+			guint32 pos = 0;
+			gdouble trn_amount;
+			
+				switch(tmpslice)
+				{
+					case GROUPBY_REPTIME_DAY:
+						pos = ope->date - from;
+						break;
+
+					case GROUPBY_REPTIME_WEEK:
+						pos = (ope->date - from)/7;
+						break;
+
+					case GROUPBY_REPTIME_MONTH:
+						pos = DateInMonth(from, ope->date);
+						break;
+
+					case GROUPBY_REPTIME_QUARTER:
+						pos = DateInQuarter(from, ope->date);
+						break;
+
+					case GROUPBY_REPTIME_YEAR:
+						pos = DateInYear(from, ope->date);
+						break;
+				}
+
+				trn_amount = 0.0;
+				
+				if( (tmpfor == FOR_REPTIME_CATEGORY) && (ope->flags & OF_SPLIT) )
+				{
+				guint nbsplit = da_splits_count(ope->splits);
+				Split *split;
+				Category *catentry;
+				
+					for(i=0;i<nbsplit;i++)
+					{
+						split = ope->splits[i];
+						catentry = da_cat_get(split->kcat);
+						if(catentry != NULL)	//#1340142
+						{
+							//#1678230 miss showall
+							if( showall == TRUE || selkey == catentry->parent || selkey == catentry->key )
+								trn_amount += split->amount;
+						}
+					}
+				}
+				else
+					trn_amount = ope->amount;
+
+				trn_amount = hb_amount_base(trn_amount, ope->kcur);
+
+				DB( g_print("** pos=%d : add of %.2f\n", pos, trn_amount) );
+
+				tmp_amount[pos] += trn_amount;
+
+			}
+
 			list = g_list_next(list);
 		}
 
@@ -1043,8 +1096,9 @@ next1:
 		gchar   buf[128];
 
 			average = cumulation / n_result;
+			data->average = average;
 
-			mystrfmon(buf, 127, average, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_minor)) );
+			hb_strfmon(buf, 127, average, kcur, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_minor)) );
 
 			////TRANSLATORS: count of transaction in balancedrawn / count of total transaction under abalancedrawn amount threshold
 			info = g_strdup_printf(_("Average: %s"), buf);
@@ -1070,28 +1124,70 @@ next1:
 static void ui_reptime_sensitive(GtkWidget *widget, gpointer user_data)
 {
 struct ui_reptime_data *data;
-gboolean active;
-gboolean sensitive;
+GtkAction *action;
+gboolean visible, sensitive;
 gint page;
 
 	DB( g_print("\n[reptime] sensitive\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	active = gtk_tree_selection_get_selected(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_report)), NULL, NULL);
-
 	page = gtk_notebook_get_current_page(GTK_NOTEBOOK(data->GR_result));
 
-	sensitive = page == 0 ? active : FALSE;
-//	gtk_widget_set_sensitive(data->TB_buttons[ACTION_REPBUDGET_DETAIL], sensitive);
-	gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/ToolBar/Detail"), sensitive);
+	visible = page == 0 ? TRUE : FALSE;
+	action = gtk_ui_manager_get_action(data->ui, "/ToolBar/Detail");
+	gtk_action_set_visible (action, visible);
+	//action = gtk_ui_manager_get_action(data->ui, "/ToolBar/Export");
+	//gtk_action_set_visible (action, visible);
+	//sensitive = gtk_tree_selection_get_selected(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_report)), NULL, NULL);
+	//gtk_action_set_sensitive(action, sensitive);
+	hb_widget_visible (data->BT_export, visible);
 
-	sensitive = page == 0 ? FALSE : TRUE;
-	gtk_widget_set_sensitive(data->LB_zoomx, sensitive);
-	gtk_widget_set_sensitive(data->RG_zoomx, sensitive);
+	visible = page == 0 ? FALSE : TRUE;
+	hb_widget_visible(data->LB_zoomx, visible);
+	hb_widget_visible(data->RG_zoomx, visible);
+
+	sensitive = gtk_tree_model_iter_n_children(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_detail)), NULL) > 0 ? TRUE : FALSE;
+	gtk_widget_set_sensitive(data->MI_detailtoclip, sensitive);
+	gtk_widget_set_sensitive(data->MI_detailtocsv, sensitive);
 
 }
 
+
+static void ui_reptime_detail_onRowActivated (GtkTreeView        *treeview,
+                       GtkTreePath        *path,
+                       GtkTreeViewColumn  *col,
+                       gpointer            userdata)
+{
+struct ui_reptime_data *data;
+Transaction *active_txn;
+gboolean result;
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(treeview), GTK_TYPE_WINDOW)), "inst_data");
+
+	DB( g_print ("\n[reptime] A detail row has been double-clicked!\n") );
+
+	active_txn = list_txn_get_active_transaction(GTK_TREE_VIEW(data->LV_detail));
+	if(active_txn)
+	{
+	Transaction *old_txn, *new_txn;
+
+		old_txn = da_transaction_clone (active_txn);
+		new_txn = active_txn;
+		result = deftransaction_external_edit(GTK_WINDOW(data->window), old_txn, new_txn);
+
+		if(result == GTK_RESPONSE_ACCEPT)
+		{
+			//#1640885
+			GLOBALS->changes_count++;
+			ui_reptime_compute(data->window, NULL);
+		}
+
+		da_transaction_free (old_txn);
+	}
+}
+
+
 static void ui_reptime_update_detail(GtkWidget *widget, gpointer user_data)
 {
 struct ui_reptime_data *data;
@@ -1206,12 +1302,13 @@ static void ui_reptime_setup(struct ui_reptime_data *data, guint32 accnum)
 {
 	DB( g_print("\n[reptime] setup\n") );
 
-	data->detail = 0;
-
+	data->txn_queue = g_queue_new ();
 
 	data->filter = da_filter_malloc();
 	filter_default_all_set(data->filter);
 
+	data->detail = 0;
+
 	/* 3.4 : make int transfer out of stats */
 	data->filter->option[FILTER_PAYMODE] = 1;
 	data->filter->paymode[PAYMODE_INTXFER] = FALSE;
@@ -1230,10 +1327,13 @@ static void ui_reptime_setup(struct ui_reptime_data *data, guint32 accnum)
 
 	DB( g_print(" populate\n") );
 	ui_acc_comboboxentry_populate(GTK_COMBO_BOX(data->PO_acc), GLOBALS->h_acc, ACC_LST_INSERT_REPORT);
-	ui_acc_comboboxentry_set_active(GTK_COMBO_BOX(data->PO_acc), accnum);
+	if( accnum )
+		ui_acc_comboboxentry_set_active(GTK_COMBO_BOX(data->PO_acc), accnum);
+	else
+		gtk_combo_box_set_active(GTK_COMBO_BOX(data->PO_acc), 0);
 
 	ui_pay_comboboxentry_populate(GTK_COMBO_BOX(data->PO_pay), GLOBALS->h_pay);
-	gtk_combo_box_set_active(GTK_COMBO_BOX(data->PO_pay), 0);
+	ui_pay_comboboxentry_set_active(GTK_COMBO_BOX(data->PO_pay), 0);
 
 	ui_cat_comboboxentry_populate(GTK_COMBO_BOX(data->PO_cat), GLOBALS->h_cat);
 	gtk_combo_box_set_active(GTK_COMBO_BOX(data->PO_cat), 0);
@@ -1275,6 +1375,8 @@ struct WinGeometry *wg;
 
 	DB( g_print("\n[reptime] dispose\n") );
 
+	g_queue_free (data->txn_queue);
+
 	da_filter_free(data->filter);
 
 	g_free(data);
@@ -1301,11 +1403,11 @@ GtkWidget *ui_reptime_window_new(guint32 accnum)
 struct ui_reptime_data *data;
 struct WinGeometry *wg;
 GtkWidget *window, *mainvbox, *hbox, *vbox, *notebook, *treeview;
-GtkWidget *label, *widget, *table, *alignment;
+GtkWidget *label, *widget, *table;
 gint row;
 GtkUIManager *ui;
 GtkActionGroup *actions;
-GtkAction *action;
+//GtkAction *action;
 GError *error = NULL;
 
 	data = g_malloc0(sizeof(struct ui_reptime_data));
@@ -1316,7 +1418,7 @@ GError *error = NULL;
 
 	//disable define windows
 	GLOBALS->define_off++;
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(2));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
 
     /* create window, etc */
     window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -1324,6 +1426,8 @@ GError *error = NULL;
 
 	//store our window private data
 	g_object_set_data(G_OBJECT(window), "inst_data", (gpointer)data);
+	DB( g_print(" - new window=%p, inst_data=%p\n", window, data) );
+
 
 	gtk_window_set_title (GTK_WINDOW (window), _("Trend Time Report"));
 
@@ -1340,29 +1444,26 @@ GError *error = NULL;
 
 	//control part
 	table = gtk_grid_new ();
-	//			gtk_alignment_new(xalign, yalign, xscale, yscale)
-	alignment = gtk_alignment_new(0.0, 0.0, 0.0, 0.0);
-	gtk_container_add(GTK_CONTAINER(alignment), table);
-    gtk_box_pack_start (GTK_BOX (hbox), alignment, FALSE, FALSE, 0);
+	gtk_widget_set_hexpand (GTK_WIDGET(table), FALSE);
+    gtk_box_pack_start (GTK_BOX (hbox), table, FALSE, FALSE, 0);
 
 	gtk_container_set_border_width (GTK_CONTAINER (table), SPACING_SMALL);
 	gtk_grid_set_row_spacing (GTK_GRID (table), SPACING_SMALL);
 	gtk_grid_set_column_spacing (GTK_GRID (table), SPACING_MEDIUM);
 
 	row = 0;
-	label = make_label(_("Display"), 0.0, 0.5);
-	gimp_label_set_attributes(GTK_LABEL(label), PANGO_ATTR_WEIGHT, PANGO_WEIGHT_BOLD, -1);
+	label = make_label_group(_("Display"));
 	gtk_grid_attach (GTK_GRID (table), label, 0, row, 3, 1);
 
 	row++;
-	label = make_label(_("_For:"), 0, 0.5);
+	label = make_label_widget(_("_For:"));
 	gtk_grid_attach (GTK_GRID (table), label, 1, row, 1, 1);
 	widget = make_cycle(label, CYA_TIMESELECT);
 	data->CY_for = widget;
 	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
 
 	row++;
-	label = make_label(_("_Account:"), 0.0, 0.5);
+	label = make_label_widget(_("A_ccount:"));
 	data->LB_acc = label;
 	gtk_grid_attach (GTK_GRID (table), label, 1, row, 1, 1);
 	widget = ui_acc_comboboxentry_new(label);
@@ -1370,7 +1471,7 @@ GError *error = NULL;
 	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
 
 	row++;
-	label = make_label(_("_Category:"), 0.0, 0.5);
+	label = make_label_widget(_("_Category:"));
 	data->LB_cat = label;
 	gtk_grid_attach (GTK_GRID (table), label, 1, row, 1, 1);
 	widget = ui_cat_comboboxentry_new(label);
@@ -1378,7 +1479,7 @@ GError *error = NULL;
 	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
 
 	row++;
-	label = make_label(_("_Payee:"), 0.0, 0.5);
+	label = make_label_widget(_("_Payee:"));
 	data->LB_pay = label;
 	gtk_grid_attach (GTK_GRID (table), label, 1, row, 1, 1);
 	widget = ui_pay_comboboxentry_new(label);
@@ -1388,27 +1489,27 @@ GError *error = NULL;
 	row++;
 	widget = gtk_check_button_new_with_mnemonic (_("Select _all"));
 	data->CM_all = widget;
-	gtk_grid_attach (GTK_GRID (table), widget, 1, row, 2, 1);
+	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
 
 	row++;
 	widget = gtk_check_button_new_with_mnemonic (_("_Cumulate"));
 	data->CM_cumul = widget;
-	gtk_grid_attach (GTK_GRID (table), widget, 1, row, 2, 1);
+	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
 
 	row++;
-	label = make_label(_("_View by:"), 0, 0.5);
+	label = make_label_widget(_("_View by:"));
 	gtk_grid_attach (GTK_GRID (table), label, 1, row, 1, 1);
 	widget = make_cycle(label, CYA_VIEWBY);
 	data->CY_view = widget;
 	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
 
 	row++;
-	widget = gtk_check_button_new_with_mnemonic (_("_Minor currency"));
+	widget = gtk_check_button_new_with_mnemonic (_("Euro _minor"));
 	data->CM_minor = widget;
-	gtk_grid_attach (GTK_GRID (table), widget, 1, row, 2, 1);
+	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
 
 	row++;
-	label = make_label(_("_Zoom X:"), 0, 0.5);
+	label = make_label_widget(_("_Zoom X:"));
 	data->LB_zoomx = label;
 	gtk_grid_attach (GTK_GRID (table), label, 1, row, 1, 1);
 	widget = make_scale(label);
@@ -1421,24 +1522,23 @@ GError *error = NULL;
 	gtk_grid_attach (GTK_GRID (table), widget, 0, row, 3, 1);
 
 	row++;
-	label = make_label(_("Date filter"), 0.0, 0.5);
-	gimp_label_set_attributes(GTK_LABEL(label), PANGO_ATTR_WEIGHT, PANGO_WEIGHT_BOLD, -1);
+	label = make_label_group(_("Date filter"));
 	gtk_grid_attach (GTK_GRID (table), label, 0, row, 3, 1);
 
 	row++;
-	label = make_label(_("_Range:"), 0, 0.5);
+	label = make_label_widget(_("_Range:"));
 	gtk_grid_attach (GTK_GRID (table), label, 1, row, 1, 1);
 	data->CY_range = make_daterange(label, FALSE);
 	gtk_grid_attach (GTK_GRID (table), data->CY_range, 2, row, 1, 1);
 
 	row++;
-	label = make_label(_("_From:"), 0, 0.5);
+	label = make_label_widget(_("_From:"));
 	gtk_grid_attach (GTK_GRID (table), label, 1, row, 1, 1);
 	data->PO_mindate = gtk_date_entry_new();
 	gtk_grid_attach (GTK_GRID (table), data->PO_mindate, 2, row, 1, 1);
 
 	row++;
-	label = make_label(_("_To:"), 0, 0.5);
+	label = make_label_widget(_("_To:"));
 	gtk_grid_attach (GTK_GRID (table), label, 1, row, 1, 1);
 	data->PO_maxdate = gtk_date_entry_new();
 	gtk_grid_attach (GTK_GRID (table), data->PO_maxdate, 2, row, 1, 1);
@@ -1449,34 +1549,36 @@ GError *error = NULL;
     gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
 
 	//ui manager
-	actions = gtk_action_group_new ("Account");
+	actions = gtk_action_group_new ("default");
 
 	//as we use gettext
    	gtk_action_group_set_translation_domain(actions, GETTEXT_PACKAGE);
 
 	// data to action callbacks is set here (data)
+	gtk_action_group_add_radio_actions (actions, radio_entries, n_radio_entries, 0, G_CALLBACK(ui_reptime_action_mode), data);
+
 	gtk_action_group_add_actions (actions, entries, n_entries, data);
 
-     gtk_action_group_add_toggle_actions (actions,
+	gtk_action_group_add_toggle_actions (actions,
 					   toggle_entries, n_toggle_entries,
 					   data);
 
 
 	/* set which action should have priority in the toolbar */
-	action = gtk_action_group_get_action(actions, "List");
-	g_object_set(action, "is_important", TRUE, NULL);
+	//action = gtk_action_group_get_action(actions, "List");
+	//g_object_set(action, "is_important", TRUE, NULL);
 
-	action = gtk_action_group_get_action(actions, "Line");
-	g_object_set(action, "is_important", TRUE, NULL);
+	//action = gtk_action_group_get_action(actions, "Line");
+	//g_object_set(action, "is_important", TRUE, NULL);
 
 	/*action = gtk_action_group_get_action(actions, "Column");
 	g_object_set(action, "is_important", TRUE, NULL);*/
 
-	action = gtk_action_group_get_action(actions, "Detail");
-	g_object_set(action, "is_important", TRUE, NULL);
+	//action = gtk_action_group_get_action(actions, "Detail");
+	//g_object_set(action, "is_important", TRUE, NULL);
 
-	action = gtk_action_group_get_action(actions, "Refresh");
-	g_object_set(action, "is_important", TRUE, NULL);
+	//action = gtk_action_group_get_action(actions, "Refresh");
+	//g_object_set(action, "is_important", TRUE, NULL);
 
 
 	ui = gtk_ui_manager_new ();
@@ -1496,6 +1598,46 @@ GError *error = NULL;
 	data->TB_bar = gtk_ui_manager_get_widget (ui, "/ToolBar");
 	gtk_box_pack_start (GTK_BOX (vbox), data->TB_bar, FALSE, FALSE, 0);
 
+	//add export menu button
+	GtkToolItem *toolitem;
+	GtkWidget *menu, *menuitem, *image;
+
+	menu = gtk_menu_new ();
+	//gtk_widget_set_halign (menu, GTK_ALIGN_END);
+
+	menuitem = gtk_menu_item_new_with_mnemonic (_("_Result to clipboard"));
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+	g_signal_connect (G_OBJECT (menuitem), "activate", G_CALLBACK (ui_reptime_export_result_clipboard), data);
+
+	menuitem = gtk_menu_item_new_with_mnemonic (_("_Result to CSV"));
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+	g_signal_connect (G_OBJECT (menuitem), "activate", G_CALLBACK (ui_reptime_export_result_csv), data);
+
+	menuitem = gtk_menu_item_new_with_mnemonic (_("_Detail to clipboard"));
+	data->MI_detailtoclip = menuitem;
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+	g_signal_connect (G_OBJECT (menuitem), "activate", G_CALLBACK (ui_reptime_export_detail_clipboard), data);
+
+	menuitem = gtk_menu_item_new_with_mnemonic (_("_Detail to CSV"));
+	data->MI_detailtocsv = menuitem;
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+	g_signal_connect (G_OBJECT (menuitem), "activate", G_CALLBACK (ui_reptime_export_detail_csv), data);
+
+	gtk_widget_show_all (menu);
+
+	widget = gtk_menu_button_new();
+	data->BT_export = widget;
+	gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET(widget)), GTK_STYLE_CLASS_FLAT);
+
+	//gtk_menu_button_set_direction (GTK_MENU_BUTTON(widget), GTK_ARROW_DOWN);
+	//gtk_widget_set_halign (widget, GTK_ALIGN_END);
+	image = gtk_image_new_from_icon_name (ICONNAME_HB_FILE_EXPORT, GTK_ICON_SIZE_LARGE_TOOLBAR);
+	g_object_set (widget, "image", image, "popup", GTK_MENU(menu),  NULL);
+
+	toolitem = gtk_tool_item_new();
+	gtk_container_add (GTK_CONTAINER(toolitem), widget);
+	gtk_toolbar_insert(GTK_TOOLBAR(data->TB_bar), GTK_TOOL_ITEM(toolitem), -1);
+
 	//infos
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
 	gtk_container_set_border_width (GTK_CONTAINER(hbox), SPACING_SMALL);
@@ -1591,6 +1733,7 @@ GError *error = NULL;
 
 	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_report)), "changed", G_CALLBACK (ui_reptime_selection), NULL);
 
+	g_signal_connect (GTK_TREE_VIEW(data->LV_detail), "row-activated", G_CALLBACK (ui_reptime_detail_onRowActivated), NULL);
 
 
 	/* toolbar */
@@ -1637,6 +1780,48 @@ GError *error = NULL;
 */
 
 
+static GString *ui_list_reptime_to_string(GtkTreeView *treeview, gboolean clipboard)
+{
+GString *node;
+GtkTreeModel *model;
+GtkTreeIter	iter;
+gboolean valid;
+const gchar *format;
+
+	node = g_string_new(NULL);
+
+	// header
+	format = (clipboard == TRUE) ? "%s\t%s\n" : "%s;%s\n";
+	g_string_append_printf(node, format, _("Time slice"), _("Amount"));
+
+	model = gtk_tree_view_get_model(treeview);
+	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
+	while (valid)
+	{
+	gchar *name;
+	gdouble amount;
+
+		gtk_tree_model_get (model, &iter,
+			//LST_REPTIME_KEY, i,
+			LST_REPTIME_TITLE  , &name,
+			LST_REPTIME_AMOUNT , &amount,
+			-1);
+
+		format = (clipboard == TRUE) ? "%s\t%.2f\n" : "%s;%.2f\n";
+		g_string_append_printf(node, format, name, amount);
+
+		//leak
+		g_free(name);
+		
+		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
+	}
+
+	//DB( g_print("text is:\n%s", node->str) );
+
+	return node;
+}
+
+
 static void ui_reptime_amount_cell_data_function (GtkTreeViewColumn *col,
                            GtkCellRenderer   *renderer,
                            GtkTreeModel      *model,
@@ -1646,14 +1831,13 @@ static void ui_reptime_amount_cell_data_function (GtkTreeViewColumn *col,
 gdouble  value;
 gchar *color;
 gchar buf[G_ASCII_DTOSTR_BUF_SIZE];
-//guint32 kcur = (guint32)g_object_get_data(G_OBJECT(gtk_tree_view_column_get_tree_view(col)), "kcur_data");
+guint32 kcur = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(gtk_tree_view_column_get_tree_view(col)), "kcur_data"));
 
 	gtk_tree_model_get(model, iter, GPOINTER_TO_INT(user_data), &value, -1);
 
 	if( value )
 	{
-		mystrfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, value, GLOBALS->minor);
-		//hb_strfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, value, kcur);
+		hb_strfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, value, kcur, GLOBALS->minor);
 
 		color = get_normal_color_amount(value);
 
@@ -1684,11 +1868,11 @@ GtkCellRenderer    *renderer;
 	return column;
 }
 
-/*
+
 static void ui_reptime_list_set_cur(GtkTreeView *treeview, guint32 kcur)
 {
-	g_object_set_data(G_OBJECT(treeview), "kcur_data", (guint32)kcur);
-}*/
+	g_object_set_data(G_OBJECT(treeview), "kcur_data", GUINT_TO_POINTER(kcur));
+}
 
 
 
@@ -1715,7 +1899,7 @@ GtkTreeViewColumn  *column;
 	view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
 	g_object_unref(store);
 
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view), PREFS->rules_hint);
+	gtk_tree_view_set_grid_lines (GTK_TREE_VIEW (view), PREFS->grid_lines);
 
 	/* column: Name */
 	column = gtk_tree_view_column_new();
